@@ -2,15 +2,9 @@
 function(series, window=nrow(series)/5, plotit=TRUE, add=FALSE, type="l", level=0.05, lhorz=TRUE, lcol=2, llty=2,...) {
 	call <- match.call()
 	data <- deparse(substitute(series))
-	if (exists("is.R") && is.function(is.R) && is.R()) {	# We are in R
-		# Now done with Depends: field require(stats)
-		if (is.null(class(series)) || class(series)[1] != "mts")
-			stop("series must be a multiple regular time series object")
-		Unit <- attr(series, "units")
-	} else {
-		# Rem: cannot test if it is a time series
-		Unit <- attr(attr(series, "tspar"), "units")
-	}
+	if (is.null(class(series)) || class(series)[1] != "mts")
+		stop("series must be a multiple regular time series object")
+	Unit <- attr(series, "units")
 	UnitTxt <- GetUnitText(series)
 	# Test the length of the serie, range and step...
 	n <- nrow(series)
@@ -42,7 +36,7 @@ function(series, window=nrow(series)/5, plotit=TRUE, add=FALSE, type="l", level=
 	res$chisq <- qchisq(1-level, ncol(series))
 	res$units.text <- UnitTxt
 	attr(res, "units") <- Unit
-		
+
 	# Do we need to plot the graph?
 	if (plotit == TRUE) {
 		if (add == TRUE) {
