@@ -2,20 +2,11 @@
 function (x, y=NULL, xmin=min(x), n=length(x), deltat=(max(x)-min(x))/(n-1), rule=1) {
 	# We use approx() for the calculations
 	# but we first need to construct xout
-	if (n <= 0) 
+	if (n <= 0)
     	stop("reglin requires n >= 1")
-    if (deltat <= 0) 
+    if (deltat <= 0)
     	stop("reglin requires deltat > 0")
 	xout <- 0:(n-1) * deltat + xmin
-	# In S+, missing values are not allowed, but in R it is OK
-	if (exists("is.R") && is.function(is.R) && is.R()) {	# We are in R
-		# Leave the series like this
-	} else {												# We are in S+
-		# Eliminate missing values
-		ok <- !(is.na(x) | is.na(y))
-		x <- x[ok]
-	   	y <- y[ok]
-	}
 	# Make sure data are sorted in increasing order according to x
 	srt <- sort.list(x)
 	x <- x[srt]
