@@ -4,14 +4,9 @@ function(x) {
 		stop("x must be a 'regul' or a 'tsd' object")
 	if (class(x) == "regul") {
 		if (ncol(x$y) == 1) y <- x$y[[1]] else y <- as.matrix(x$y)
-		# The treatment is different in R ans in S+
-		# In R, we create a 'ts' object, in S+, we create a 'rts' object
-		if (exists("is.R") && is.function(is.R) && is.R()) {	# We are in R
-			res <- ts(y, start=x$tspar$start, frequency=x$tspar$frequency)
-			attr(res, "units") <- x$units
-		} else {												# We are in S+
-			res <- rts(y, start=x$tspar$start, frequency=x$tspar$frequency, units=x$units)
-		}
+		# we create a 'ts' object
+		res <- ts(y, start=x$tspar$start, frequency=x$tspar$frequency)
+		attr(res, "units") <- x$units
 	}
 	if (class(x) == "tsd") {
 		if (length(x$ts) == 1) {		# We have a decomposition of a single series
@@ -28,11 +23,7 @@ function(x) {
 			}
 			dimnames(res)[[2]] <- cnames
 		}
-		if (exists("is.R") && is.function(is.R) && is.R()) {	# We are in R
-			attr(res, "units") <- x$units
-		} else {												# We are in Splus
-			attr(attr(res, "tspar"), "units") <- x$units
-		}
+		attr(res, "units") <- x$units
 	}
 	res
 }
